@@ -9,6 +9,7 @@ require Exporter;
 	     min
 	     max
 	     minmax
+	     myround
 	    );
 
 sub min {
@@ -34,6 +35,12 @@ sub minmax {
 }
 
 
+sub myround {
+  0+sprintf("%.2f",shift);
+}
+
+
+
 
 1;
 __END__
